# google-sign
![Python 3637 package](https://github.com/ffreemt/google-sign/workflows/Python%203637%20package/badge.svg) [![codecov](https://codecov.io/gh/ffreemt/google-sign/branch/master/graph/badge.svg)](https://codecov.io/gh/ffreemt/google-sign) ![status](https://img.shields.io/badge/status-alpha-orange.svg)

Calculate sign string for google translate and baidu translate
